@@ -21,11 +21,11 @@ macro_rules! ident_tag (
             match tag!($i, $tok) {
                 Err(e) => Err(e),
                 Ok((i, o)) => {
+                    use nom::{character::is_alphanumeric, Err as NomErr, error::ErrorKind};
                     let mut res = Ok((i, o));
                     if let Some(&c) = i.as_bytes().first() {
-                        use $crate::nom::{Context, Err, ErrorKind, is_alphanumeric};
                         if is_alphanumeric(c) || c == b'_' || c == b'-' {
-                            res = Err(Err::Error(Context::Code($i, ErrorKind::Tag::<u32>)));
+                            res = Err(NomErr::Error(($i, ErrorKind::Tag)));
                         }
                     }
                     res
@@ -109,6 +109,9 @@ generate_terms_for_names! {
     /// Represents the terminal symbol `optional`
     Optional => "optional",
 
+    /// Represents the terminal symbol `async`
+    Async => "async",
+
     /// Represents the terminal symbol `attribute`
     Attribute => "attribute",
 
@@ -238,8 +241,8 @@ generate_terms_for_names! {
     /// Represents the terminal symbol `unsigned`
     Unsigned => "unsigned",
 
-    /// Represents the terminal symbol `void`
-    Void => "void",
+    /// Represents the terminal symbol `undefined`
+    Undefined => "undefined",
 
     /// Represents the terminal symbol `record`
     Record => "record",
@@ -300,6 +303,9 @@ generate_terms_for_names! {
 
     /// Represents the terminal symbol `legacycaller`
     LegacyCaller => "legacycaller",
+
+    /// Represents the terminal symbol `constructor`
+    Constructor => "constructor",
 }
 
 #[macro_export]
@@ -358,6 +364,9 @@ macro_rules! term {
     (optional) => {
         $crate::term::Optional
     };
+    (async) => {
+        $crate::term::Async
+    };
     (attribute) => {
         $crate::term::Attribute
     };
@@ -487,8 +496,8 @@ macro_rules! term {
     (unsigned) => {
         $crate::term::Unsigned
     };
-    (void) => {
-        $crate::term::Void
+    (undefined) => {
+        $crate::term::Undefined
     };
     (record) => {
         $crate::term::Record
@@ -550,6 +559,9 @@ macro_rules! term {
     (legacycaller) => {
         $crate::term::LegacyCaller
     };
+    (constructor) => {
+        $crate::term::Constructor
+    };
 }
 
 #[cfg(test)]
@@ -559,41 +571,40 @@ mod test {
             $(
                 mod $m {
                     use super::super::$typ;
-                    use Parse;
-                    use nom::types::CompleteStr;
+                    use crate::Parse;
 
                     #[test]
                     fn should_parse() {
-                        let (rem, parsed) = $typ::parse(CompleteStr(concat!($string))).unwrap();
-                        assert_eq!(rem, CompleteStr(""));
+                        let (rem, parsed) = $typ::parse(concat!($string)).unwrap();
+                        assert_eq!(rem, "");
                         assert_eq!(parsed, $typ);
                     }
 
                     #[test]
                     fn should_parse_with_preceding_spaces() {
-                        let (rem, parsed) = $typ::parse(CompleteStr(concat!("  ", $string))).unwrap();
-                        assert_eq!(rem, CompleteStr(""));
+                        let (rem, parsed) = $typ::parse(concat!("  ", $string)).unwrap();
+                        assert_eq!(rem, "");
                         assert_eq!(parsed, $typ);
                     }
 
                     #[test]
                     fn should_parse_with_succeeding_spaces() {
-                        let (rem, parsed) = $typ::parse(CompleteStr(concat!($string, "  "))).unwrap();
-                        assert_eq!(rem, CompleteStr(""));
+                        let (rem, parsed) = $typ::parse(concat!($string, "  ")).unwrap();
+                        assert_eq!(rem, "");
                         assert_eq!(parsed, $typ);
                     }
 
                     #[test]
                     fn should_parse_with_surrounding_spaces() {
-                        let (rem, parsed) = $typ::parse(CompleteStr(concat!("  ", $string, "  "))).unwrap();
-                        assert_eq!(rem, CompleteStr(""));
+                        let (rem, parsed) = $typ::parse(concat!("  ", $string, "  ")).unwrap();
+                        assert_eq!(rem, "");
                         assert_eq!(parsed, $typ);
                     }
 
                     #[test]
                     fn should_parse_if_anything_next() {
-                        let (rem, parsed) = $typ::parse(CompleteStr(concat!($string, "  anything"))).unwrap();
-                        assert_eq!(rem, CompleteStr("anything"));
+                        let (rem, parsed) = $typ::parse(concat!($string, "  anything")).unwrap();
+                        assert_eq!(rem, "anything");
                         assert_eq!(parsed, $typ);
                     }
                 }
@@ -620,6 +631,7 @@ mod test {
         qmark, QMark, "?";
         or, Or, "or";
         optional, Optional, "optional";
+        async_, Async, "async";
         attribute, Attribute, "attribute";
         callback, Callback, "callback";
         const_, Const, "const";
@@ -663,7 +675,7 @@ mod test {
         short, Short, "short";
         true_, True, "true";
         unsigned, Unsigned, "unsigned";
-        void, Void, "void";
+        undefined, Undefined, "undefined";
         record, Record, "record";
         arraybuffer, ArrayBuffer, "ArrayBuffer";
         dataview, DataView, "DataView";
@@ -680,5 +692,6 @@ mod test {
         error, Error, "Error";
         implements, Implements, "implements";
         legacycaller, LegacyCaller, "legacycaller";
+        constructor, Constructor, "constructor";
     ];
 }
